#ifndef __ATTRIB_DLG_H
#define __ATTRIB_DLG_H
/*-------------------------------------------------------------------------
 * Copyright (c) 1999-2001 Kenneth W. Sodemann (stufflehead@bigfoot.com)
 *-------------------------------------------------------------------------
 * attrib_dlg
 *
 * Synopsis:
 *   Routines used to display the options dialog box, which is used
 *   to edit various options within the system.
 *   
 * $Id: attrib_dlg.h,v 1.11 2001/11/28 18:53:20 stuffle Exp $
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to
 * Free Software Foundation, Inc.
 * 59 Temple Place, Suite 330
 * Boston, MA  02111-1307  USA
 *
 *-------------------------------------------------------------------------
 */

#include <gtk/gtk.h>
#include <libpq-fe.h>

/*-------------------------------------------------------------------------
 * Function:  destroy_attrib_dlg
 *
 * Synopsis:
 *   If the attribute list dialog exists, destroy it.
 *
 * Inputs:
 *   None.
 *
 * Outputs:
 *   None.
 * 
 * Return Value:
 *   None.
 *
 *-------------------------------------------------------------------------
 */
void destroy_attrib_dlg (void);

/*-------------------------------------------------------------------------
 * Function:  show_attrib_dlg
 *
 * Synopsis:
 *   Create the attribute dialog.  If it already exists, make sure it is
 *   visible.
 *
 * Inputs:
 *   parent        : pointer to the parent widget set
 *   conn          : pointer to the database connection
 *   user_is_admin : TRUE if user is admin user, FALSE otherwise
 *
 * Outputs:
 *   None.
 * 
 * Return Value:
 *   None.
 *
 *-------------------------------------------------------------------------
 */
void show_attrib_dlg (GtkWidget  *parent,
                      PGconn     *conn,
                      gboolean user_is_admin);

/*-------------------------------------------------------------------------
 * Function:  attrib_dlg_dirty
 *
 * Synopsis:
 *   Determine if there is any unsaved attribute information.
 *
 * Inputs:
 *   None.
 *
 * Outputs:
 *   None.
 *
 * Return Value:
 *   TRUE  : there is unsaved attribute information.
 *   FALSE : there is NOT unsaved attribute information.
 *
 *-------------------------------------------------------------------------
 */
gboolean attrib_dlg_dirty (void);
#endif
