#ifndef __MAINWIN_H
#define __MAINWIN_H
/*-------------------------------------------------------------------------
 * Copyright (c) 1999-2003 Kenneth W. Sodemann (stuffle@charter.net)
 *-------------------------------------------------------------------------
 * mainwin
 *
 * Synopsis:
 *   Create and manipulate the main window for the application.
 *
 * $Id: mainwin.h,v 1.11 2003/02/22 21:15:14 stuffle Exp $
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to
 * Free Software Foundation, Inc.
 * 59 Temple Place, Suite 330
 * Boston, MA  02111-1307  USA
 *
 *-------------------------------------------------------------------------
 */
#include <gconf/gconf-client.h>
#include <gtk/gtk.h>
#include <libpq-fe.h>

/*-------------------------------------------------------------------------
 * Function: create_main_win
 *
 * Synopsis:
 *   Create the main window.
 *
 * Inputs:
 *   conn : pointer to the database connection.
 *   client : pointer to the GConf client the application should use.
 *
 * Outputs:
 *   None.
 * 
 * Return Value:
 *   A pointer to the main window widget.
 *
 *-------------------------------------------------------------------------
 */
GtkWidget* create_main_win (PGconn  *conn, GConfClient *client);


/*-------------------------------------------------------------------------
 * Function: refresh_query_combo
 *
 * Synopsis:
 *   Refresh the query combo on the main window.
 *
 * Inputs:
 *   main_win: pointer to the main window.
 *
 * Outputs:
 *   None.
 * 
 * Return Value:
 *   None.
 *
 *-------------------------------------------------------------------------
 */
void refresh_query_combo (GtkWidget *main_win);


/*-------------------------------------------------------------------------
 * Function: refresh_project_list
 *
 * Synopsis:
 *   Refresh the project list for the main window.
 *
 * Inputs:
 *   main_win: pointer to the main window.
 *
 * Outputs:
 *   None.
 * 
 * Return Value:
 *   None.
 *
 *-------------------------------------------------------------------------
 */
void refresh_project_list (GtkWidget *main_win);


/*-------------------------------------------------------------------------
 * Function: refresh_pr_list
 *
 * Synopsis:
 *   Refresh the PR list for the main window using the current criteria
 *   that is selected on the main window.
 *
 * Inputs:
 *   main_win: pointer to the main window.
 *
 * Outputs:
 *   None.
 * 
 * Return Value:
 *   None.
 *
 *-------------------------------------------------------------------------
 */
void refresh_pr_list (GtkWidget *main_win);

#if 0
/*-------------------------------------------------------------------------
 * Function: set_auto_refresh_time
 *
 * Synopsis:
 *   Set the auto refresh target value.  This function should be 
 *   called if the auto refresh value is changed.
 *
 * Inputs:
 *   main_win: pointer to the main window.
 *
 * Outputs:
 *   None.
 * 
 * Return Value:
 *   None.
 *
 *-------------------------------------------------------------------------
 */
void set_auto_refresh_time (GtkWidget *main_win);
#endif

#endif
