#ifndef __PERSON_DLG_H
#define __PERSON_DLG_H
/*-------------------------------------------------------------------------
 * Copyright (c) 1999-2001 Kenneth W. Sodemann (stufflehead@bigfoot.com)
 *-------------------------------------------------------------------------
 * person_dlg
 *
 * Synopsis:
 *   Handle the user list dialog.
 *
 * $Id: person_dlg.h,v 1.10 2001/11/28 18:53:20 stuffle Exp $
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to
 * Free Software Foundation, Inc.
 * 59 Temple Place, Suite 330
 * Boston, MA  02111-1307  USA
 *
 *-------------------------------------------------------------------------
 */
#include <gtk/gtk.h>
#include <libpq-fe.h>

/*-------------------------------------------------------------------------
 * Function: destroy_person_dlg
 *
 * Synopsis:
 *   If the person list dialog box exists, destroy it.
 *
 * Inputs:
 *   None.
 *
 * Outputs:
 *   None.
 * 
 * Return Value:
 *   None.
 *
 *-------------------------------------------------------------------------
 */
void destroy_person_dlg (void);

/*-------------------------------------------------------------------------
 * Function: show_person_dlg
 *
 * Synopsis:
 *   Create, fill, and display the person list dialog box.  If the
 *   dialog box is already displayed, make it visible.
 *
 * Inputs:
 *   parent        : pointer to the parent widget set.
 *   conn          : pointer to the database connection used to fill
 *                   the list.
 *   user_is_admin : specify whether or not the current user is
 *                   an admin user. 
 *
 * Outputs:
 *   None.
 * 
 * Return Value:
 *   None.
 *
 *-------------------------------------------------------------------------
 */
void show_person_dlg (GtkWidget *parent, 
                      PGconn    *conn,
                      gboolean   user_is_admin);

/*-------------------------------------------------------------------------
 * Function:  person_dlg_dirty
 *
 * Synopsis:
 *   Determine if there is any unsaved person information.
 *
 * Inputs:
 *   None.
 *
 * Outputs:
 *   None.
 *
 * Return Value:
 *   TRUE  : there is unsaved person information.
 *   FALSE : there is NOT unsaved person information.
 *
 *-------------------------------------------------------------------------
 */
gboolean person_dlg_dirty (void);
#endif
