#ifndef __PRINT_DLG_H
#define __PRINT_DLG_H
/*-------------------------------------------------------------------------
 * Copyright (c) 1999-2000 Kenneth W. Sodemann (stufflehead@bigfoot.com)
 *-------------------------------------------------------------------------
 * print_dlg
 *
 * Synopsis:
 *    Determine what to print and where to print it.
 *
 * $Id: print_dlg.h,v 1.2 2000/11/23 13:23:36 stuffle Exp $
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to
 * Free Software Foundation, Inc.
 * 59 Temple Place, Suite 330
 * Boston, MA  02111-1307  USA
 *
 *-------------------------------------------------------------------------
 */
#include <gtk/gtk.h>
#include <libpq-fe.h>

/*-------------------------------------------------------------------------
 * Function:  create_print_dlg
 *
 * Synopsis:
 *   Get data from the user as to what to print, and where to print
 *   it (printer, file, etc.)
 *
 * Inputs:
 *   parent : pointer to the widget set that created this one
 *   conn   : pointer to the database connection
 *   list   : list of PKs for all PRs currently listed
 *   sel    : list of currently selected PR(s)
 *
 * Outputs:
 *   None.
 * 
 * Return Value:
 *   Pointer to the created print dlg.
 *
 *-------------------------------------------------------------------------
 */
GtkWidget *create_print_dlg (GtkWidget  *parent,
                             PGconn     *conn,
                             GList      *list,
                             GList      *sel);


/*-------------------------------------------------------------------------
 * Function:  execute_print_dlg
 *
 * Synopsis:
 *   Execute as a modal dialog.
 *
 * Inputs:
 *   parent : pointer to the widget set that created this one
 *   conn   : pointer to the database connection
 *   list   : list of PKs for all PRs currently listed
 *   sel    : list of currently selected PR(s)
 *
 * Outputs:
 *   None.
 * 
 * Return Value:
 *   Integer representing the button pressed to leave the dialog.
 *
 *-------------------------------------------------------------------------
 */
gint execute_print_dlg (GtkWidget  *parent,
                        PGconn     *conn,
                        GList      *list,
                        GList      *sel);


#endif
