#ifndef __PRINT_PROG_DLG_H
#define __PRINT_PROG_DLG_H
/*-------------------------------------------------------------------------
 * Copyright (c) 1999-2002 Kenneth W. Sodemann (stufflehead@bigfoot.com)
 *-------------------------------------------------------------------------
 * print_prog_dlg
 *
 * Synopsis:
 *    Printing progress dialog box
 *
 * $Id: print_prog_dlg.h,v 1.4 2002/11/22 20:53:06 stuffle Exp $
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to
 * Free Software Foundation, Inc.
 * 59 Temple Place, Suite 330
 * Boston, MA  02111-1307  USA
 *
 *-------------------------------------------------------------------------
 */
#include <gtk/gtk.h>

/*-------------------------------------------------------------------------
 * Function: create_print_prog_dlg
 *
 * Synopsis:
 *   Create the printing progress dialog box.
 *
 * Inputs:
 *   Parent : this dialog's parent window.
 *
 * Outputs:
 *   None.
 * 
 * Return Value:
 *   A pointer to the printing progress dialog box.
 *
 *-------------------------------------------------------------------------
 */
GtkWidget *create_print_prog_dlg (GtkWidget *parent);

/*-------------------------------------------------------------------------
 * Function: print_prog_dlg_printing_complete
 *
 * Synopsis:
 *   Perform whatever processing is required by the progress dialog
 *   once the printing is complete.
 *
 * Inputs:
 *   dlg : The progress dialog box.
 *
 * Outputs:
 *   None.
 * 
 * Return Value:
 *   None.
 *
 *-------------------------------------------------------------------------
 */
void print_prog_dlg_printing_complete (GtkWidget  *dlg); 

/*-------------------------------------------------------------------------
 * Function:
 *   print_prog_dlg_output_message
 *
 * Synopsis:
 *   Output a message in the print progress dialog.
 *
 * Inputs:
 *   dlg     : The dialog that should print the message.
 *   str     : The message to output.
 *   warning : Set TRUE for warning messages, FALSE otherwise
 *
 * Outputs:
 *   None.
 * 
 * Return Value:
 *   None.
 *
 *-------------------------------------------------------------------------
 */
void print_prog_dlg_output_message (GtkWidget   *dlg,
                                    const gchar *str,
                                    gboolean     warning);
#endif
