#ifndef __PROBUPDATE_DLG_H
#define __PROBUPDATE_DLG_H
/*-------------------------------------------------------------------------
 * Copyright (c) 1999-2005 Kenneth W. Sodemann (stuffle@mac.com)
 *-------------------------------------------------------------------------
 * probupdate_dlg
 *
 * Synopsis:
 *    Dialog used for entering new problem reports and editing or 
 *    viewing existing problem reports.  This started out as just 
 *    an editing and viewing window, but morphed into the one window
 *    used for all actions, which helps keep things consistent for
 *    the user.
 *
 * $Id: probupdate_dlg.h,v 1.9 2005/02/19 03:08:37 stuffle Exp $
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to
 * Free Software Foundation, Inc.
 * 59 Temple Place, Suite 330
 * Boston, MA  02111-1307  USA
 *
 *-------------------------------------------------------------------------
 */
#include <gtk/gtk.h>
#include <libpq-fe.h>

/*-------------------------------------------------------------------------
 * Function:  create_problem_update_dlg
 *
 * Synopsis:
 *   Create the dialog box used to update and view problem reports 
 *   that are in the system.
 *
 *   Use this function to create non-modal dialog boxes.  The create
 *   modal dialog, use the execute_xxx function.
 *
 * Inputs:
 *   parent : pointer to the widget set that created this one, this 
 *            should always be the main window of the application
 *   conn   : pointer to the database connection
 *   pr_pk  : The primary key for the current PR.  Enter INVALID_PK
 *            to enter a new problem report.
 *
 * Outputs:
 *   None.
 * 
 * Return Value:
 *   Pointer to the dialog box's main widget.
 *
 *-------------------------------------------------------------------------
 */
GtkWidget *create_problem_update_dlg (GtkWidget  *parent,
                                      PGconn     *conn,
                                      gint        pr_pk);

/*-------------------------------------------------------------------------
 * Function:  problem_update_dlg_dirty
 *
 * Synopsis:
 *   Determine if we can close the update dialog box.
 *
 * Inputs:
 *   dlg : pointer to the dialog to check.
 *
 * Outputs:
 *   None.
 * 
 * Return Value:
 *   TRUE  : The dialog can be closed.
 *   FALSE : The dialog cannot be closed.
 *
 *-------------------------------------------------------------------------
 */
gboolean problem_update_dlg_dirty (GtkWidget *dlg);

#endif
