#ifndef __PROJECT_DLG_H
#define __PROJECT_DLG_H
/*-------------------------------------------------------------------------
 * Copyright (c) 1999-2001 Kenneth W. Sodemann (stufflehead@bigfoot.com)
 *-------------------------------------------------------------------------
 * project_dlg
 *
 * Synopsis:
 *   Within PRepS, only a single project list dialog can be displayed
 *   at any one time.  The public functions in this module are used to
 *   create/raise that dialog, and to destroy it.
 *
 *
 * $Id: project_dlg.h,v 1.10 2001/11/28 18:53:20 stuffle Exp $
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to
 * Free Software Foundation, Inc.
 * 59 Temple Place, Suite 330
 * Boston, MA  02111-1307  USA
 *
 *-------------------------------------------------------------------------
 */

#include <gtk/gtk.h>
#include <libpq-fe.h>

/*-------------------------------------------------------------------------
 * Function:  destroy_project_dlg
 *
 * Synopsis:
 *   If the project list dialog exists, destroy it.
 *
 * Inputs:
 *   None.
 *
 * Outputs:
 *   None.
 * 
 * Return Value:
 *   None.
 *
 *-------------------------------------------------------------------------
 */
void destroy_project_dlg (void);

/*-------------------------------------------------------------------------
 * Function:  show_project_dlg
 *
 * Synopsis:
 *   Create the project list dialog that is then used to add,
 *   modify, and delete projects.  If the dialog already exists,
 *   make it visible.
 *
 * Inputs:
 *   parent        : pointer to the widget set that created this one,
 *                   should always be the main application window.
 *   conn          : pointer to the database connection.
 *   user_is_admin : specify whether or not the current user is
 *                   an admin user.
 *
 * Outputs:
 *   None.
 * 
 * Return Value:
 *   None.
 *
 *-------------------------------------------------------------------------
 */
void show_project_dlg (GtkWidget  *parent,
                       PGconn     *conn,
                       gboolean    user_is_admin);


/*-------------------------------------------------------------------------
 * Function:  project_dlg_dirty
 *
 * Synopsis:
 *   Determine if there is any unsaved project information.
 *
 * Inputs:
 *   None.
 *
 * Outputs:
 *   None.
 * 
 * Return Value:
 *   TRUE  : there is unsaved project information.
 *   FALSE : there is NOT unsaved project information.
 *
 *-------------------------------------------------------------------------
 */
gboolean project_dlg_dirty (void);
#endif
