#ifndef __QUERY_DLG_H
#define __QUERY_DLG_H
/*-------------------------------------------------------------------------
 * Copyright (c) 1999-2001 Kenneth W. Sodemann (stufflehead@bigfoot.com)
 *-------------------------------------------------------------------------
 * query_dlg
 *
 * Synopsis:
 *    Create and edit problem report queries.
 *
 * $Id: query_dlg.h,v 1.7 2001/11/28 18:53:20 stuffle Exp $
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to
 * Free Software Foundation, Inc.
 * 59 Temple Place, Suite 330
 * Boston, MA  02111-1307  USA
 *
 *-------------------------------------------------------------------------
 */

#include <glib.h>
#include <gtk/gtk.h>
#include <libpq-fe.h>

/*-------------------------------------------------------------------------
 * Function: destroy_query_dlg
 *
 * Synopsis:
 *   If any query list dialogs exist, destroy them.
 *
 * Inputs:
 *   None.
 *
 * Outputs:
 *   None.
 * 
 * Return Value:
 *   None.
 *
 *-------------------------------------------------------------------------
 */
void destroy_query_dlg (void);


/*-------------------------------------------------------------------------
 * Function: show_query_dlg
 *
 * Synopsis:
 *   If the given query dialog already exists, raise it to the top.
 *   Otherwise, create the query dialog box.  This dialog box just
 *   shows a list of the current system or user queries.
 *
 * Inputs:
 *   parent    : the calling widget
 *   conn      : the current database connection
 *   is_system : TRUE if this is a system query, FALSE if this is
 *               a user query
 *   user_is_admin : TRUE if the current user has admin access, FALSE 
 *                   otherwise
 *
 * Outputs:
 *   None.
 * 
 * Return Value:
 *   None.
 *
 *-------------------------------------------------------------------------
 */
void show_query_dlg (GtkWidget   *parent,
                     PGconn      *conn,
                     gboolean     is_system,
                     gboolean     user_is_admin);


/*-------------------------------------------------------------------------
 * Function:  query_dlg_dirty
 *
 * Synopsis:
 *   Determine if there is any unsaved query information.
 *
 * Inputs:
 *   None.
 *
 * Outputs:
 *   None.
 *
 * Return Value:
 *   TRUE  : there is unsaved query information.
 *   FALSE : there is NOT unsaved query information.
 *
 *-------------------------------------------------------------------------
 */
gboolean query_dlg_dirty (void);
#endif
